summaryrefslogtreecommitdiff
path: root/misc
diff options
context:
space:
mode:
Diffstat (limited to 'misc')
-rw-r--r--misc/tabledrag.js7
1 files changed, 5 insertions, 2 deletions
diff --git a/misc/tabledrag.js b/misc/tabledrag.js
index baebfcfd4..867f9c344 100644
--- a/misc/tabledrag.js
+++ b/misc/tabledrag.js
@@ -1016,8 +1016,11 @@ Drupal.tableDrag.prototype.row.prototype.validIndentInterval = function (prevRow
minIndent = nextRow ? $('.indentation', nextRow).size() : 0;
// Maximum indentation:
- if (!prevRow || $(this.element).is('.tabledrag-root')) {
- // Do not indent the first row in the table or 'root' rows..
+ if (!prevRow || $(prevRow).is(':not(.draggable)') || $(this.element).is('.tabledrag-root')) {
+ // Do not indent:
+ // - the first row in the table,
+ // - rows dragged below a non-draggable row,
+ // - 'root' rows.
maxIndent = 0;
}
else {